@@ -11,5 +11,5 @@
 ******************************************************************************/
 
 /* General cman bits */
-extern void write_cman_pipe(char *message);
+extern int write_cman_pipe(char *message);
 extern void close_cman_pipe(void);
