@@ -1,3 +1,14 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) 2005-2008 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
 #include <getopt.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -30,6 +41,7 @@
 #include "commands.h"
 #include "barrier.h"
 #include "ais.h"
+#include "cman.h"
 
 LOGSYS_DECLARE_SUBSYS (CMAN_NAME, LOG_INFO);
 
@@ -255,8 +267,8 @@ static int process_client(poll_handle handle, int fd, int revent, void *data)
 			uint8_t port;
 			struct sock_data_header *dmsg = (struct sock_data_header *)msg;
 
-			P_DAEMON("sending %lu bytes of data to node %d, port %d\n",
-				 (unsigned long)(msg->length - sizeof(struct sock_data_header)), dmsg->nodeid, dmsg->port);
+			P_DAEMON("sending %d bytes of data to node %d, port %d\n",
+				 msg->length - sizeof(struct sock_data_header), dmsg->nodeid, dmsg->port);
 
 			buf += sizeof(struct sock_data_header);
 
@@ -396,6 +408,7 @@ static int open_local_sock(const char *name, int name_len, mode_t mode, poll_han
 	}
 	con->type = type;
 	con->fd = local_socket;
+	con->num_write_msgs = 0;
 
 	poll_dispatch_add(handle, con->fd, POLLIN, con, process_rendezvous);
 
