@@ -1,3 +1,25 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) 2004-2007 Red Hat, Inc.  All rights reserved.
+**
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2 of the License, or (at your option) any later version.
+**
+**  This library is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
+**
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+**
+*******************************************************************************
+******************************************************************************/
+
 #include <sys/types.h>
 #include <sys/un.h>
 #include <inttypes.h>
@@ -346,7 +368,7 @@ int cman_finish(cman_handle_t handle)
 	return 0;
 }
 
-int cman_setprivdata(cman_handle_t handle, void *privdata)
+int cman_setprivdata(cman_handle_t *handle, void *privdata)
 {
 	struct cman_handle *h = (struct cman_handle *)handle;
 	VALIDATE_HANDLE(h);
@@ -355,7 +377,7 @@ int cman_setprivdata(cman_handle_t handle, void *privdata)
 	return 0;
 }
 
-int cman_getprivdata(cman_handle_t handle, void **privdata)
+int cman_getprivdata(cman_handle_t *handle, void **privdata)
 {
 	struct cman_handle *h = (struct cman_handle *)handle;
 	VALIDATE_HANDLE(h);
@@ -464,7 +486,6 @@ int cman_dispatch(cman_handle_t handle, int flags)
 			res = process_cman_message(h, flags, smsg->msg);
 			h->saved_reply_msg = smsg->next;
 			len = smsg->msg->length;
-			free(smsg->msg);
 			free(smsg);
 			if (res || (flags & CMAN_DISPATCH_ONE))
 				break;
@@ -478,7 +499,6 @@ int cman_dispatch(cman_handle_t handle, int flags)
 			res = process_cman_message(h, flags, smsg->msg);
 			h->saved_data_msg = smsg->next;
 			len = smsg->msg->length;
-			free(smsg->msg);
 			free(smsg);
 			if (res || (flags & CMAN_DISPATCH_ONE))
 				break;
@@ -492,7 +512,6 @@ int cman_dispatch(cman_handle_t handle, int flags)
 			res = process_cman_message(h, flags, smsg->msg);
 			h->saved_event_msg = smsg->next;
 			len = smsg->msg->length;
-			free(smsg->msg);
 			free(smsg);
 			if (res || (flags & CMAN_DISPATCH_ONE))
 				break;
@@ -1094,3 +1113,13 @@ int cman_node_fenced(cman_handle_t handle, int nodeid, uint64_t time, char *agen
 	strcpy(f.fence_agent, agent);
 	return info_call(h, CMAN_CMD_UPDATE_FENCE_INFO, &f, sizeof(f), NULL, 0);
 }
+
+#ifdef DEBUG
+int cman_dump_objdb(cman_handle_t handle, char *filename)
+{
+	struct cman_handle *h = (struct cman_handle *)handle;
+	VALIDATE_HANDLE(h);
+
+	return info_call(h, CMAN_CMD_DUMP_OBJDB, filename, strlen(filename)+1, NULL, 0);
+}
+#endif
