@@ -1,3 +1,23 @@
+/**
+  Copyright Red Hat, Inc. 2006
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by the
+  Free Software Foundation; either version 2, or (at your option) any
+  later version.
+
+  This program is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; see the file COPYING.  If not, write to the
+  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge, 
+  MA 02139, USA.
+
+  Author: Lon Hohberger <lhh at redhat.com>
+ */
 /**
   @file Quorum daemon scoring functions + thread.
  */
@@ -11,7 +31,7 @@
 #include <pthread.h>
 #include <string.h>
 #include <ccs.h>
-#include <clulog.h>
+#include <openais/service/logsys.h>
 #include <sched.h>
 #include <sys/mman.h>
 #include "disk.h"
@@ -29,11 +49,12 @@ struct h_arg {
 	int count;
 };
 
+LOGSYS_DECLARE_SUBSYS ("QDISK", LOG_LEVEL_INFO);
 
 /*
   XXX Messy, but works for now... 
  */
-static void
+void
 nullify(void)
 {
 	int fd[3];
@@ -58,7 +79,7 @@ nullify(void)
   Set all signal handlers to default for exec of a script.
   ONLY do this after a fork().
  */
-static void
+void
 restore_signals(void)
 {
 	sigset_t set;
@@ -126,7 +147,7 @@ fork_heuristic(struct h_data *h)
 
 	execv("/bin/sh", argv);
 
-	printf("Execv failed\n");
+	log_printf(LOG_ERR, "Execv failed\n");
 	return 0;
 }
 
@@ -142,7 +163,7 @@ total_score(struct h_data *h, int max, int *score, int *maxscore)
 	*score = 0;
 	*maxscore = 0;
 	
-	//printf("max = %d\n", max);
+	log_printf(LOG_DEBUG, "max = %d\n", max);
 	/* Allow operation w/o any heuristics */
 	if (!max) {
 		*score = *maxscore = 1;
@@ -191,7 +212,7 @@ check_heuristic(struct h_data *h, int block)
 	/* Returned 0 and was not killed */
 	if (!h->available) {
 		h->available = 1;
-		clulog(LOG_INFO, "Heuristic: '%s' UP\n", h->program);
+		log_printf(LOG_INFO, "Heuristic: '%s' UP\n", h->program);
 	}
 	h->misses = 0;
 	return 0;
@@ -200,12 +221,12 @@ miss:
 	if (h->available) {
 		h->misses++;
 		if (h->misses >= h->tko) {
-			clulog(LOG_INFO,
+			log_printf(LOG_INFO,
 				"Heuristic: '%s' DOWN (%d/%d)\n",
 				h->program, h->misses, h->tko);
 			h->available = 0;
 		} else {
-			clulog(LOG_DEBUG,
+			log_printf(LOG_DEBUG,
 				"Heuristic: '%s' missed (%d/%d)\n",
 				h->program, h->misses, h->tko);
 		}
@@ -304,13 +325,13 @@ configure_heuristics(int ccsfd, struct h_data *h, int max)
 				h[x].tko = 1;
 		}
 
-		clulog(LOG_DEBUG,
+		log_printf(LOG_DEBUG,
 		       "Heuristic: '%s' score=%d interval=%d tko=%d\n",
 		       h[x].program, h[x].score, h[x].interval, h[x].tko);
 
 	} while (++x < max);
 
-	clulog(LOG_DEBUG, "%d heuristics loaded\n", x);
+	log_printf(LOG_DEBUG, "%d heuristics loaded\n", x);
 		
 	return x;
 }
@@ -348,7 +369,7 @@ fudge_scoring(void)
 /**
   Loop for the scoring thread.
  */
-static void *
+void *
 score_thread_main(void *arg)
 {
 	struct h_arg *args = (struct h_arg *)arg;
@@ -372,11 +393,29 @@ score_thread_main(void *arg)
 
 	free(args->h);
 	free(args);
-	printf("Score thread going away\n");
+	log_printf(LOG_INFO, "Score thread going away\n");
 	return (NULL);
 }
 
 
+/**
+  Stop the score thread for shutdown / reconfiguration
+ */
+int
+stop_score_thread(void)
+{
+	void *ret;
+
+	if (!_score_thread_running)
+		return 0;
+
+	_score_thread_running = 0;
+	pthread_join(score_thread, &ret);
+
+	return 0;
+}
+
+
 /**
   Start the score thread.  h is copied into an argument which is
   passed in as the arg parameter in the score thread, so it is safe
@@ -418,3 +457,35 @@ start_score_thread(qd_ctx *ctx, struct h_data *h, int count)
 	_score_thread_running = 0;
 	return -1;	
 }
+
+
+#if 0
+int
+main(int argc, char **argv)
+{
+	struct h_data h[10];
+	int max = 0, score, maxscore, ccsfd;
+
+	ccsfd = ccs_force_connect("test", 1);
+	if (ccsfd < 0) 
+		return -1;
+	max = configure_heuristics(ccsfd, h, 10);
+	ccs_disconnect(ccsfd);
+	
+	start_score_thread(h, max);
+	max = 0;
+	while (max < 10) {
+		get_my_score(&score,&maxscore);
+		log_printf(LOG_INFO, "current %d/%d\n", score, maxscore);
+		sleep(1);
+		++max;
+	}
+	stop_score_thread();
+
+	get_my_score(&score,&maxscore);
+	log_printf(LOG_INFO, "final! %d/%d\n", score, maxscore);
+
+	return 0;
+}
+#endif
+
