@@ -1,3 +1,15 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004-2007 Red Hat, Inc.  All rights reserved.
+**  
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
 #include "do_rack.h"
 
 char *pname = "fence_rack";
@@ -440,7 +452,10 @@ int main(int argc, char **argv)
   }
   writebuf[sizeof(char)+(strlen(username))+1+(strlen(password))+1] ='\n';
      
-  write(sock,writebuf,sizeof(char)+strlen(username)+strlen(password)+2);
+  if(write(sock,writebuf,sizeof(char)+strlen(username)+strlen(password)+2) < 0) {
+    fprintf(stderr,"failed to write to socket\n");
+    exit(DID_FAILURE);
+  }
    
   /********************************************
    ***
@@ -466,7 +481,10 @@ int main(int argc, char **argv)
  
  writebuf[0] = configuration_request;
  writebuf[1] = config_general;
- write(sock,writebuf,2*(sizeof(char)));
+ if(write(sock,writebuf,2*(sizeof(char))) < 0) {
+   fprintf(stderr,"failed to write to socket\n");
+   exit(DID_FAILURE);
+ }
 
  /********************************************
    ***
@@ -618,7 +636,10 @@ int main(int argc, char **argv)
  writebuf[(pnumb*5)+3] = (char)(pnumb);
  writebuf[(pnumb*5)+4] = action_offon;
 
- write(sock,writebuf,(pnumb*5)+5);
+ if(write(sock,writebuf,(pnumb*5)+5) < 0) {
+   fprintf(stderr,"failed to write to socket\n");
+   exit(DID_FAILURE);
+ }
  if(verbose_flag){
    printf("%s: sending action frame to switch:\n",name);
    for(i=0;i<(pnumb*5)+5;i++) 
@@ -635,7 +656,10 @@ int main(int argc, char **argv)
  writebuf[0] = configuration_request;
  writebuf[1] = boardnum;
  
- write(sock,writebuf,2*(sizeof(char)));
+ if(write(sock,writebuf,2*(sizeof(char))) < 0) {
+   fprintf(stderr,"failed to write to socket\n");
+   exit(DID_FAILURE);
+ }
  if(verbose_flag){
    printf("%s: sending Request Configuration Frame from switch:\n",name);
    printf("0x%.2x 0x%.2x\n",writebuf[0],writebuf[1]);
