@@ -1277,29 +1277,44 @@ int set_domain_info(struct fd *fd, struct fenced_domain *domain)
 	return 0;
 }
 
-int set_domain_members(struct fd *fd, int *member_count,
-		       struct fenced_node **members)
+int set_domain_nodes(struct fd *fd, int option, int *node_count,
+		     struct fenced_node **nodes_out)
 {
 	struct change *cg = fd->started_change;
-	struct fenced_node *nodes, *nodep;
+	struct fenced_node *nodes = NULL, *n;
+	struct node_history *nh;
 	struct member *memb;
+	int count = 0;
 
-	if (!cg) {
-		*member_count = 0;
-		return 0;
+	if (option == FENCED_NODES_MEMBERS) {
+		if (!cg)
+			goto out;
+		count = cg->member_count;
+
+		nodes = malloc(count * sizeof(struct fenced_node));
+		if (!nodes)
+			return -ENOMEM;
+
+		n = nodes;
+		list_for_each_entry(memb, &cg->members, list)
+			set_node_info(fd, memb->nodeid, n++);
 	}
 
-	nodes = malloc(cg->member_count * sizeof(struct fenced_node));
-	if (!nodes)
-		return -ENOMEM;
+	else if (option == FENCED_NODES_ALL) {
+		list_for_each_entry(nh, &fd->node_history, list)
+			count++;
 
-	nodep = nodes;
-	list_for_each_entry(memb, &cg->members, list) {
-		set_node_info(fd, memb->nodeid, nodep++);
+		nodes = malloc(count * sizeof(struct fenced_node));
+		if (!nodes)
+			return -ENOMEM;
+
+		n = nodes;
+		list_for_each_entry(nh, &fd->node_history, list)
+			set_node_info(fd, nh->nodeid, n++);
 	}
-
-	*member_count = cg->member_count;
-	*members = nodes;
+ out:
+	*node_count = count;
+	*nodes_out = nodes;
 	return 0;
 }
 
