@@ -2,7 +2,7 @@
 *******************************************************************************
 **
 **  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
-**  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
+**  Copyright (C) 2004-2006 Red Hat, Inc.  All rights reserved.
 **
 **  This copyrighted material is made available to anyone wishing to use,
 **  modify, copy, or redistribute it subject to the terms and conditions
@@ -14,6 +14,6 @@
 #ifndef __MOUNT_DOT_H__
 #define __MOUNT_DOT_H__
 
-int gfs_make_args(char *data, struct gfs_args *args);
+int gfs_make_args(char *data, struct gfs_args *args, int remount);
 
 #endif /* __MOUNT_DOT_H__ */
