@@ -1,8 +1,21 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004-2006 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
 #include <linux/sched.h>
 #include <linux/slab.h>
 #include <linux/smp_lock.h>
 #include <linux/spinlock.h>
-#include <linux/semaphore.h>
+#include <asm/semaphore.h>
 #include <linux/completion.h>
 #include <linux/buffer_head.h>
 #include <asm/uaccess.h>
@@ -93,11 +106,11 @@ gfs_llseek(struct file *file, loff_t offset, int origin)
 	if (origin == 2) {
 		error = gfs_glock_nq_init(ip->i_gl, LM_ST_SHARED, LM_FLAG_ANY, &i_gh);
 		if (!error) {
-			error = generic_file_llseek_unlocked(file, offset, origin);
+			error = remote_llseek(file, offset, origin);
 			gfs_glock_dq_uninit(&i_gh);
 		}
 	} else
-		error = generic_file_llseek_unlocked(file, offset, origin);
+		error = remote_llseek(file, offset, origin);
 
 	return error;
 }
@@ -270,37 +283,6 @@ do_read_readi(struct file *file, char *buf, size_t size, loff_t *offset,
 	return count;
 }
 
-/**
- * grope_mapping - feel up a mapping that needs to be written
- * @buf: the start of the memory to be written
- * @size: the size of the memory to be written
- *
- * We do this after acquiring the locks on the mapping,
- * but before starting the write transaction.  We need to make
- * sure that we don't cause recursive transactions if blocks
- * need to be allocated to the file backing the mapping.
- *
- * Returns: errno
- */
-
-static int
-grope_mapping(char *buf, size_t size)
-{
-	unsigned long start = (unsigned long)buf;
-	unsigned long stop = start + size;
-	char c;
-
-	while (start < stop) {
-		if (copy_from_user(&c, (char *)start, 1))
-			return -EFAULT;
-
-		start += PAGE_CACHE_SIZE;
-		start &= PAGE_CACHE_MASK;
-	}
-
-	return 0;
-}
-
 /**
  * do_read_direct - Read bytes from a file
  * @file: The file to read from
@@ -337,12 +319,6 @@ do_read_direct(struct file *file, char *buf, size_t size, loff_t *offset,
 
 	gfs_holder_init(ip->i_gl, state, flags, &ghs[num_gh]);
 
-	if (num_gh && atomic_read(&current->mm->mm_users) > 1) {
-		error = grope_mapping(buf, size);
-		if (error)
-			goto out;
-	}
-
 	error = gfs_glock_nq_m(num_gh + 1, ghs);
 	if (error)
 		goto out;
@@ -406,12 +382,6 @@ do_read_buf(struct file *file, char *buf, size_t size, loff_t *offset,
 
 	gfs_holder_init(ip->i_gl, LM_ST_SHARED, GL_ATIME, &ghs[num_gh]);
 
-	if (num_gh && atomic_read(&current->mm->mm_users) > 1) {
-		error = grope_mapping(buf, size);
-		if (error)
-			goto out;
-	}
-
 	error = gfs_glock_nq_m_atime(num_gh + 1, ghs);
 	if (error)
 		goto out;
@@ -481,6 +451,37 @@ gfs_aio_read(struct kiocb *iocb, const struct iovec *iov, unsigned long count,
 	return(__gfs_read(filp, iov->iov_base, iov->iov_len, &iocb->ki_pos, iocb));
 }
 
+/**
+ * grope_mapping - feel up a mapping that needs to be written
+ * @buf: the start of the memory to be written
+ * @size: the size of the memory to be written
+ *
+ * We do this after acquiring the locks on the mapping,
+ * but before starting the write transaction.  We need to make
+ * sure that we don't cause recursive transactions if blocks
+ * need to be allocated to the file backing the mapping.
+ *
+ * Returns: errno
+ */
+
+static int
+grope_mapping(char *buf, size_t size)
+{
+	unsigned long start = (unsigned long)buf;
+	unsigned long stop = start + size;
+	char c;
+
+	while (start < stop) {
+		if (copy_from_user(&c, (char *)start, 1))
+			return -EFAULT;
+
+		start += PAGE_CACHE_SIZE;
+		start &= PAGE_CACHE_MASK;
+	}
+
+	return 0;
+}
+
 /**
  * gfs_file_aio_write_nolock - Call vfs aio layer to write bytes to a file
  * @file: The file to write to
@@ -683,12 +684,6 @@ do_write_direct(struct file *file, char *buf, size_t size, loff_t *offset,
  restart:
 	gfs_holder_init(ip->i_gl, state, 0, &ghs[num_gh]);
 
-	if (num_gh && atomic_read(&current->mm->mm_users) > 1) {
-		error = grope_mapping(buf, size);
-		if (error)
-			goto out;
-	}
-
 	error = gfs_glock_nq_m(num_gh + 1, ghs);
 	if (error)
 		goto out;
@@ -977,12 +972,6 @@ do_write_buf(struct file *file,
 
 	gfs_holder_init(ip->i_gl, LM_ST_EXCLUSIVE, 0, &ghs[num_gh]);
 
-	if (num_gh && atomic_read(&current->mm->mm_users) > 1) {
-		error = grope_mapping(buf, size);
-		if (error)
-			goto out;
-	}
-
 	error = gfs_glock_nq_m(num_gh + 1, ghs);
 	if (error)
 		goto out;
@@ -1156,29 +1145,6 @@ filldir_reg_func(void *opaque,
 	return 0;
 }
 
-static inline int
-high_stat_rate(struct gfs_inode *ip)
-{
-	struct timeval now, diff;
-	unsigned long milli = 0;
-	unsigned int rate = 0; /* stats per second in this dir */
-
-	do_gettimeofday(&now);
-	diff.tv_sec = now.tv_sec - ip->i_dir_stat_st.tv_sec;
-	diff.tv_usec = now.tv_usec - ip->i_dir_stat_st.tv_usec;
-	if (diff.tv_usec < 0) {
-		diff.tv_usec += 1000000;
-		diff.tv_sec--;
-	}
-	milli = (diff.tv_sec * 1000) + (diff.tv_usec / 1000);
-	if (milli)
-		rate = (ip->i_dir_stats * 1000) / milli;
-
-	if (rate > 10) /* More than 10 stats/sec */
-		return 1;
-	return 0;
-}
-
 /**
  * readdir_reg - Read directory entries from a directory
  * @file: The directory to read from
@@ -1198,14 +1164,10 @@ readdir_reg(struct file *file, void *dirent, filldir_t filldir)
 	int error;
 
 	fdr.fdr_sbd = dip->i_sbd;
-	fdr.fdr_prefetch = high_stat_rate(dip) ? TRUE : FALSE;
+	fdr.fdr_prefetch = TRUE;
 	fdr.fdr_filldir = filldir;
 	fdr.fdr_opaque = dirent;
 
-	/* reset stat counter and timestamp */
-	dip->i_dir_stats = 0;
-	do_gettimeofday(&dip->i_dir_stat_st);
-
 	gfs_holder_init(dip->i_gl, LM_ST_SHARED, GL_ATIME, &d_gh);
 	error = gfs_glock_nq_atime(&d_gh);
 	if (error) {
@@ -1654,12 +1616,6 @@ gfs_lock(struct file *file, int cmd, struct file_lock *fl)
 	if ((ip->i_di.di_mode & (S_ISGID | S_IXGRP)) == S_ISGID)
 		return -ENOLCK;
 
-	if (cmd == F_CANCELLK) {
-		/* Hack: */
-		cmd = F_SETLK;
-		fl->fl_type = F_UNLCK;
-	}
-
 	if (IS_GETLK(cmd))
 		return gfs_lm_plock_get(sdp, &name, file, fl);
 	else if (fl->fl_type == F_UNLCK)
