@@ -1,3 +1,16 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004-2007 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
 #include "util.h"
 #include "file.h"
 #include "rgrp.h"
@@ -12,7 +25,7 @@
 #define IS_LEAF     (1)
 #define IS_DINODE   (2)
 
-#define dir_hash(qstr) (gfs_dir_hash((char *)(qstr)->name, (qstr)->len))
+#define dir_hash(qstr) (gfs_dir_hash((qstr)->name, (qstr)->len))
 
 /* Detect directory is a stuffed inode */
 int fsck_inode_is_stuffed(struct fsck_inode *ip)
@@ -451,7 +464,7 @@ static int linked_leaf_search(struct fsck_inode *dip, identifier_t *id,
  */
 static int dir_e_search(struct fsck_inode *dip, identifier_t *id, unsigned int *type)
 {
-	osi_buf_t *bh = NULL;
+	osi_buf_t *bh;
 	struct gfs_dirent *dent;
 	int error;
 
