@@ -1,3 +1,16 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
 /* Large chunks of this code were lifted from nbd.c */
 
 #include <linux/major.h>
@@ -56,26 +69,25 @@ static spinlock_t gnbd_lock = SPIN_LOCK_UNLOCKED;
 
 #define to_gnbd_dev(d) container_of(d, struct gnbd_device, class_dev)
 
-static void gnbd_class_release(struct class_device *class_dev)
+static void gnbd_class_release(struct device *class_dev)
 {
 	/* FIXME -- What the hell do I have to free up here */
 }
 
 static struct class gnbd_class = {
 	.name = "gnbd",
-	.release = gnbd_class_release
+	.dev_release = gnbd_class_release
 };
 
-
-static ssize_t show_pid(struct class_device *class_dev, char *buf)
+static ssize_t show_pid(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%d\n", dev->receiver_pid);
 }
 
-static CLASS_DEVICE_ATTR(pid, S_IRUGO, show_pid, NULL);
+DEVICE_ATTR(pid, S_IRUGO, show_pid, NULL);
 
-static ssize_t show_server(struct class_device *class_dev, char *buf)
+static ssize_t show_server(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	if (dev->server_name)
@@ -86,7 +98,7 @@ static ssize_t show_server(struct class_device *class_dev, char *buf)
 }
 
 /* FIXME -- should a empty store free the memory */
-static ssize_t store_server(struct class_device *class_dev,
+static ssize_t store_server(struct device *class_dev, struct device_attribute *attr,
 		const char *buf, size_t count)
 {
 	int res;
@@ -116,15 +128,15 @@ static ssize_t store_server(struct class_device *class_dev,
 	return count;
 }
 
-CLASS_DEVICE_ATTR(server, S_IRUGO | S_IWUSR, show_server, store_server);
+DEVICE_ATTR(server, S_IRUGO | S_IWUSR, show_server, store_server);
 
-static ssize_t show_name(struct class_device *class_dev, char *buf)
+static ssize_t show_name(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%s\n", dev->name);
 }
 
-static ssize_t store_name(struct class_device *class_dev,
+static ssize_t store_name(struct device *class_dev, struct device_attribute *attr,
                 const char *buf, size_t count)
 {
 	int res;
@@ -138,17 +150,17 @@ static ssize_t store_name(struct class_device *class_dev,
 	return count;
 }
 
-CLASS_DEVICE_ATTR(name, S_IRUGO | S_IWUSR, show_name, store_name);
+DEVICE_ATTR(name, S_IRUGO | S_IWUSR, show_name, store_name);
 
 
-static ssize_t show_sectors(struct class_device *class_dev, char *buf)
+static ssize_t show_sectors(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%Lu\n",
 			(unsigned long long)get_capacity(dev->disk));
 }
 
-static ssize_t store_sectors(struct class_device *class_dev,
+static ssize_t store_sectors(struct device *class_dev, struct device_attribute *attr,
 		const char *buf, size_t count)
 {
 	int res;
@@ -177,23 +189,23 @@ static ssize_t store_sectors(struct class_device *class_dev,
 	return count;
 }
 
-CLASS_DEVICE_ATTR(sectors, S_IRUGO | S_IWUSR, show_sectors, store_sectors);
+DEVICE_ATTR(sectors, S_IRUGO | S_IWUSR, show_sectors, store_sectors);
 
-static ssize_t show_usage(struct class_device *class_dev, char *buf)
+static ssize_t show_usage(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%d\n", dev->open_count);
 }
 
-CLASS_DEVICE_ATTR(usage, S_IRUGO, show_usage, NULL);
+DEVICE_ATTR(usage, S_IRUGO, show_usage, NULL);
 
-static ssize_t show_flags(struct class_device *class_dev, char *buf)
+static ssize_t show_flags(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "0x%04x\n", dev->flags);
 }
 
-static ssize_t store_flags(struct class_device *class_dev,
+static ssize_t store_flags(struct device *class_dev, struct device_attribute *attr,
                 const char *buf, size_t count)
 {
 	int res;
@@ -209,9 +221,9 @@ static ssize_t store_flags(struct class_device *class_dev,
 }
 
 
-CLASS_DEVICE_ATTR(flags, S_IRUGO | S_IWUSR, show_flags, store_flags);
+DEVICE_ATTR(flags, S_IRUGO | S_IWUSR, show_flags, store_flags);
 
-static ssize_t show_waittime(struct class_device *class_dev, char *buf)
+static ssize_t show_waittime(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	if (list_empty(&dev->queue_head))
@@ -220,15 +232,15 @@ static ssize_t show_waittime(struct class_device *class_dev, char *buf)
 			((long)jiffies - (long)dev->last_received) / HZ);
 }
 
-CLASS_DEVICE_ATTR(waittime, S_IRUGO, show_waittime, NULL);
+DEVICE_ATTR(waittime, S_IRUGO, show_waittime, NULL);
 
-static ssize_t show_connected(struct class_device *class_dev, char *buf)
+static ssize_t show_connected(struct device *class_dev, struct device_attribute *attr, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%d\n", (dev->sock != NULL));
 }
 
-CLASS_DEVICE_ATTR(connected, S_IRUGO, show_connected, NULL);
+DEVICE_ATTR(connected, S_IRUGO, show_connected, NULL);
 
 #ifndef NDEBUG
 static const char *ioctl_cmd_to_ascii(int cmd)
@@ -254,26 +266,6 @@ static const char *gnbdcmd_to_ascii(int cmd)
 }
 #endif /* NDEBUG */
 
-
-static int wait_for_send(struct request *req, struct gnbd_device *dev)
-{
-	DECLARE_WAITQUEUE(wait, current);
-
-	add_wait_queue(&dev->tx_wait, &wait);
-	while(dev->current_request == req) {
-		set_current_state(TASK_INTERRUPTIBLE);
-		if (signal_pending(current)) {
-			printk(KERN_WARNING "gnbd (pid %d: %s) wait interrupted by signal\n",
-				current->pid, current->comm);
-			return -EINTR;
-		}
-		schedule();
-	}
-	set_current_state(TASK_RUNNING);
-	remove_wait_queue(&dev->tx_wait, &wait);
-	return 0;
-}
-
 static void gnbd_end_request(struct request *req)
 {
 	int error = req->errors ? -EIO : 0;
@@ -389,12 +381,6 @@ int __gnbd_send_req(struct gnbd_device *dev, struct socket *sock,
 
 	down(&dev->tx_lock);
 
-	if (dev->corrupt) {
-		printk(KERN_ERR "%s: Attempted to send on a faulty socket\n",
-		       dev->disk->disk_name);
-		result = -EBADFD;
-		goto error_out;
-	}
 	if (!sock) {
 		printk(KERN_ERR "%s: Attempted send on closed socket\n",
 				dev->disk->disk_name);
@@ -407,14 +393,13 @@ int __gnbd_send_req(struct gnbd_device *dev, struct socket *sock,
 			gnbdcmd_to_ascii(gnbd_cmd(req)),
 			(unsigned long long)req->sector << 9,
 			req->nr_sectors << 9);
-	dev->current_request = req;
 	result = sock_xmit(sock, 1, &request, sizeof(request),
 			(gnbd_cmd(req) == GNBD_CMD_WRITE)? MSG_MORE: 0,
 			can_signal);
 	if (result < 0) {
 		printk(KERN_ERR "%s: Send control failed (result %d)\n",
 				dev->disk->disk_name, result);
-		goto send_error_out;
+		goto error_out;
 	}
 
 	if (gnbd_cmd(req) == GNBD_CMD_WRITE) {
@@ -437,19 +422,13 @@ int __gnbd_send_req(struct gnbd_device *dev, struct socket *sock,
 				printk(KERN_ERR "%s: Send data failed (result %d)\n",
 						dev->disk->disk_name,
 						result);
-				goto send_error_out;
+				goto error_out;
 			}
 		}
 	}
-	dev->current_request = NULL;
-	wake_up(&dev->tx_wait);
 	up(&dev->tx_lock);
 	return 0;
 
-send_error_out:
-	dev->corrupt = 1;
-	dev->current_request = NULL;
-	wake_up(&dev->tx_wait);
 error_out:
 	up(&dev->tx_lock);
 	return result;
@@ -510,11 +489,6 @@ int gnbd_do_it(struct gnbd_device *dev)
 	BUG_ON(dev->magic != GNBD_MAGIC);
 
 	while((result = sock_xmit(sock, 0, &reply,sizeof(reply), MSG_WAITALL, 1)) > 0){
-		if (dev->corrupt) {
-			printk(KERN_ERR "%s: faulty socket\n",dev->disk->disk_name);
-			return -EBADFD;
-		}
-
 		if (ntohl(reply.magic) == GNBD_KEEP_ALIVE_MAGIC)
 			/* FIXME -- I should reset the wait time here */
 			continue;
@@ -549,9 +523,6 @@ int gnbd_do_it(struct gnbd_device *dev)
 				return result;
 		}
 remove_req:
-		result = wait_for_send(req, dev);
-		if (result != 0)
-			return result;
 		spin_lock(&dev->queue_lock);
 		list_del_init(&req->queuelist);
 		dev->last_received = jiffies;
@@ -564,9 +535,8 @@ remove_req:
 	return result;
 }
 
-int gnbd_clear_que(struct gnbd_device *dev)
+void gnbd_clear_que(struct gnbd_device *dev)
 {
-	int err;
 	struct request *req;
 
 	BUG_ON(dev->magic != GNBD_MAGIC);
@@ -575,9 +545,6 @@ int gnbd_clear_que(struct gnbd_device *dev)
 		req = NULL;
 		if (!list_empty(&dev->queue_head)) {
 			req = list_entry(dev->queue_head.next, struct request, queuelist);
-			err = wait_for_send(req, dev);
-			if (err)
-				return err;
 			list_del_init(&req->queuelist);
 		}
 		if (req && req != &ping_req) {
@@ -585,8 +552,6 @@ int gnbd_clear_que(struct gnbd_device *dev)
 			gnbd_end_request(req);
 		}
 	} while (req);
-
-	return 0;
 }
 
 /*
@@ -740,9 +705,7 @@ static int gnbd_ctl_ioctl(struct inode *inode, struct file *file,
 		if (down_interruptible(&dev->do_it_lock))
 			return -EBUSY;
 		dev->receiver_pid = -1;
-		error = gnbd_clear_que(dev);
-		if (error)
-			return error;
+		gnbd_clear_que(dev);
 		bdev = dev->bdev;
 		if (bdev) {
 			blk_run_queue(dev->disk->queue);
@@ -784,7 +747,6 @@ static int gnbd_ctl_ioctl(struct inode *inode, struct file *file,
 		}
 		dev->file = file;
 		dev->sock = SOCKET_I(inode);
-		dev->corrupt = 0;
 		dev->receiver_pid = current->pid; 
 		blk_run_queue(dev->disk->queue);
 		error = gnbd_do_it(dev);
@@ -958,7 +920,7 @@ static int __init gnbd_init(void)
 	gnbd_cmd(&ping_req) = GNBD_CMD_PING;
 	ping_req.sector = 0;
 	ping_req.nr_sectors = 0;
-	
+
 	for (i = 0; i < MAX_GNBD; i++) {
 		struct gendisk *disk = alloc_disk(1);
 		if (!disk)
@@ -975,7 +937,7 @@ static int __init gnbd_init(void)
 			goto out;
 		}
 		elevator_exit(disk->queue->elevator);
-		err = elevator_init(disk->queue, "deadline");
+		err = elevator_init(disk->queue, "anticipatory");
 		if (err) {
 			blk_cleanup_queue(disk->queue);
 			put_disk(disk);
@@ -1011,38 +973,36 @@ static int __init gnbd_init(void)
 		INIT_LIST_HEAD(&gnbd_dev[i].queue_head);
 		init_MUTEX(&gnbd_dev[i].tx_lock);
 		init_MUTEX(&gnbd_dev[i].do_it_lock);
-		init_waitqueue_head(&gnbd_dev[i].tx_wait);
-		gnbd_dev[i].current_request = NULL;
 		gnbd_dev[i].class_dev.class = &gnbd_class;
-		sprintf(gnbd_dev[i].class_dev.class_id, "gnbd%d", i);
-		err = class_device_register(&gnbd_dev[i].class_dev);
+		sprintf(gnbd_dev[i].class_dev.bus_id, "gnbd%d", i);
+		err = device_register(&gnbd_dev[i].class_dev);
 		if (err){
-			printk("class_device_register failed with %d\n", err);
+			printk("device_register failed with %d\n", err);
 			goto out_unregister_class;
 		}
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_pid))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_pid))
 			goto out_remove_file;
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_server))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_server))
 			goto out_remove_file;
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_name))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_name))
 			goto out_remove_file;
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_sectors))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_sectors))
 			goto out_remove_file;
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_usage))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_usage))
 			goto out_remove_file;
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_flags))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_flags))
 			goto out_remove_file;
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_waittime))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_waittime))
 			goto out_remove_file;
-		if(class_device_create_file(&gnbd_dev[i].class_dev,
-					&class_device_attr_connected))
+		if(device_create_file(&gnbd_dev[i].class_dev,
+					&dev_attr_connected))
 			goto out_remove_file;
 		disk->major = major_nr;
 		disk->first_minor = i;
@@ -1068,11 +1028,11 @@ static int __init gnbd_init(void)
 out_remove_disk:
 	del_gendisk(gnbd_dev[i].disk);
 out_remove_file:
-	class_device_unregister(&gnbd_dev[i].class_dev);
+	device_unregister(&gnbd_dev[i].class_dev);
 out_unregister_class:
 	while(i--){
 		del_gendisk(gnbd_dev[i].disk);
-		class_device_unregister(&gnbd_dev[i].class_dev);
+		device_unregister(&gnbd_dev[i].class_dev);
 	}
 	i = MAX_GNBD;
 	class_unregister(&gnbd_class);
@@ -1093,7 +1053,7 @@ static void __exit gnbd_cleanup(void)
 	gnbd_ctl_cleanup();
 	for (i = 0; i < MAX_GNBD; i++) {
 		struct gendisk *disk = gnbd_dev[i].disk;
-		class_device_unregister(&gnbd_dev[i].class_dev);
+		device_unregister(&gnbd_dev[i].class_dev);
 		if (disk) {
 			del_gendisk(disk);
 			blk_cleanup_queue(disk->queue);
