@@ -1,3 +1,16 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
 #ifndef LINUX_GNBD_H
 #define LINUX_GNBD_H
 
@@ -15,7 +28,7 @@ enum {
 	GNBD_CMD_PING = 3
 };
 
-#define gnbd_cmd(req) ((req)->cmd[0])
+#define gnbd_cmd(req) ((req)->__cmd[0])
 #define MAX_GNBD 128
 
 /* values for flags field */
@@ -37,15 +50,12 @@ struct gnbd_device {
 	pid_t receiver_pid;
 	struct semaphore do_it_lock;
 	int open_count;
-	struct class_device class_dev;
+	struct device class_dev;
 	unsigned short int server_port;
 	char *server_name;
 	char name[32];
 	unsigned long last_received;
 	struct block_device *bdev;
-	struct request *current_request;
-	wait_queue_head_t tx_wait;
-	int corrupt;
 };
 
 #endif /* __KERNEL__ */
