@@ -367,7 +367,10 @@ static int read_debugfs_master(struct lockspace *ls)
 		return -1;
 
 	/* skip the header on the first line */
-	fgets(line, LOCK_LINE_MAX, file);
+	if (!fgets(line, LOCK_LINE_MAX, file)) {
+		log_error("Unable to read %s: %d", path, errno);
+		goto out;
+	}
 
 	while (fgets(line, LOCK_LINE_MAX, file)) {
 		memset(&lock, 0, sizeof(struct pack_lock));
@@ -435,7 +438,10 @@ static int read_debugfs_locks(struct lockspace *ls)
 		return -1;
 
 	/* skip the header on the first line */
-	fgets(line, LOCK_LINE_MAX, file);
+	if (!fgets(line, LOCK_LINE_MAX, file)) {
+		log_error("Unable to read %s: %d", path, errno);
+		goto out;
+	}
 
 	while (fgets(line, LOCK_LINE_MAX, file)) {
 		memset(&lock, 0, sizeof(struct pack_lock));
