@@ -42,21 +42,20 @@
 #include <signal.h>
 #include <sys/time.h>
 #include <dirent.h>
-
 #include <openais/saAis.h>
 #include <openais/saCkpt.h>
 #include <openais/cpg.h>
 
+#include <linux/dlmconstants.h>
+#include "libdlmcontrol.h"
 #include "dlm_controld.h"
 #include "list.h"
 #include "linux_endian.h"
 
-/* Maximum lockspace name length, should match MAX_LOCKSPACE_NAME in
-   linux/dlmconstants.h (copied in libdlm.h).  The libcpg limit is
-   larger at CPG_MAX_NAME_LENGTH 128.  Our cpg name includes a "dlm:"
-   prefix before the lockspace name. */
-
-#define MAX_LS_NAME	64
+/* DLM_LOCKSPACE_LEN: maximum lockspace name length, from linux/dlmconstants.h.
+   Copied in libdlm.h so apps don't need to include the kernel header.
+   The libcpg limit is larger at CPG_MAX_NAME_LENGTH 128.  Our cpg name includes
+   a "dlm:" prefix before the lockspace name. */
 
 /* Maximum members of a lockspace, should match CPG_MEMBERS_MAX in openais/cpg.h.
    There are no max defines in dlm-kernel for lockspace members. */
@@ -72,10 +71,6 @@
 
 #define MAXLINE		256
 
-/* Size of the circular debug buffer. */
-
-#define DUMP_SIZE	(1024 * 1024)
-
 extern int daemon_debug_opt;
 extern int daemon_quit;
 extern int poll_fencing;
@@ -88,9 +83,11 @@ extern struct list_head lockspaces;
 extern int cman_quorate;
 extern int our_nodeid;
 extern char daemon_debug_buf[256];
-extern char dump_buf[DUMP_SIZE];
+extern char dump_buf[DLMC_DUMP_SIZE];
 extern int dump_point;
 extern int dump_wrap;
+extern char plock_dump_buf[DLMC_DUMP_SIZE];
+extern int plock_dump_len;
 
 void daemon_dump_save(void);
 
@@ -156,7 +153,7 @@ struct dlm_header {
 
 struct lockspace {
 	struct list_head	list;
-	char			name[MAX_LS_NAME+1];
+	char			name[DLM_LOCKSPACE_LEN+1];
 	uint32_t		global_id;
 
 	/* lockspace membership stuff */
@@ -169,6 +166,7 @@ struct lockspace {
 	int			kernel_stopped;
 	int			fs_registered;
 	uint32_t		change_seq;
+	uint32_t		started_count;
 	struct change		*started_change;
 	struct list_head	changes;
 	struct list_head	node_history;
@@ -207,7 +205,7 @@ int set_sysfs_control(char *name, int val);
 int set_sysfs_event_done(char *name, int val);
 int set_sysfs_id(char *name, uint32_t id);
 int set_configfs_members(char *name, int new_count, int *new_members,
-			 int renew_count, int *renew_members);
+			int renew_count, int *renew_members);
 void clear_configfs(void);
 int add_configfs_node(int nodeid, char *addr, int addrlen, int local);
 void del_configfs_node(int nodeid);
@@ -223,12 +221,18 @@ int dlm_join_lockspace(struct lockspace *ls);
 int dlm_leave_lockspace(struct lockspace *ls);
 char *msg_name(int type);
 void update_flow_control_status(void);
+int set_node_info(struct lockspace *ls, int nodeid, struct dlmc_node *node);
+int set_lockspace_info(struct lockspace *ls, struct dlmc_lockspace *lockspace);
+int set_lockspaces(int *count, struct dlmc_lockspace **lss_out);
+int set_lockspace_nodes(struct lockspace *ls, int option, int *node_count,
+			struct dlmc_node **nodes_out);
+int set_fs_notified(struct lockspace *ls, int nodeid);
 
 /* deadlock.c */
 void setup_deadlock(void);
 void send_cycle_start(struct lockspace *ls);
 void receive_checkpoint_ready(struct lockspace *ls, struct dlm_header *hd,
-			      int len);
+			int len);
 void receive_cycle_start(struct lockspace *ls, struct dlm_header *hd, int len);
 void receive_cycle_end(struct lockspace *ls, struct dlm_header *hd, int len);
 void receive_cancel_lock(struct lockspace *ls, struct dlm_header *hd, int len);
@@ -269,13 +273,20 @@ void close_plock_checkpoint(struct lockspace *ls);
 void store_plocks(struct lockspace *ls);
 void retrieve_plocks(struct lockspace *ls);
 void purge_plocks(struct lockspace *ls, int nodeid, int unmount);
-int dump_plocks(char *name, int fd);
+int fill_plock_dump_buf(struct lockspace *ls);
 
 /* group.c */
 int setup_groupd(void);
 void process_groupd(int ci);
 int dlm_join_lockspace_group(struct lockspace *ls);
 int dlm_leave_lockspace_group(struct lockspace *ls);
+int set_node_info_group(struct lockspace *ls, int nodeid,
+			struct dlmc_node *node);
+int set_lockspace_info_group(struct lockspace *ls,
+			struct dlmc_lockspace *lockspace);
+int set_lockspaces_group(int *count, struct dlmc_lockspace **lss_out);
+int set_lockspace_nodes_group(struct lockspace *ls, int option, int *node_count,
+			struct dlmc_node **nodes);
 
 #endif
 
