@@ -26,7 +26,7 @@
 
 group_handle_t gh;
 static int cb_action;
-static char cb_name[MAX_LS_NAME+1];
+static char cb_name[DLM_LOCKSPACE_LEN+1];
 static int cb_event_nr;
 static unsigned int cb_id;
 static int cb_type;
@@ -240,3 +240,29 @@ int setup_groupd(void)
 	return rv;
 }
 
+/* FIXME: most of the query info doesn't apply in the LIBGROUP mode,
+   but we can emulate some basic parts of it */
+
+int set_lockspace_info_group(struct lockspace *ls,
+			     struct dlmc_lockspace *lockspace)
+{
+	return 0;
+}
+
+int set_node_info_group(struct lockspace *ls, int nodeid,
+			struct dlmc_node *node)
+{
+	return 0;
+}
+
+int set_lockspaces_group(int *count, struct dlmc_lockspace **lss_out)
+{
+	return 0;
+}
+
+int set_lockspace_nodes_group(struct lockspace *ls, int option, int *node_count,
+			      struct dlmc_node **nodes_out)
+{
+	return 0;
+}
+
