@@ -1,3 +1,15 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) 2005 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
 #include <sys/types.h>
 #include <sys/un.h>
 #include <inttypes.h>
@@ -233,7 +245,7 @@ char *state_str(group_data_t *data)
 		snprintf(buf, 127, "%s %d %llx %d",
 			 ev_state_str(data->event_state),
 			 data->event_nodeid,
-			 data->event_id,
+			 (unsigned long long)data->event_id,
 			 data->event_local_status);
 	else
 		snprintf(buf, 127, "%s", ev_state_str(data->event_state));
@@ -415,7 +427,7 @@ int do_plock_dump(int argc, char **argv, int fd)
 
 	rv = do_write(fd, outbuf, sizeof(outbuf));
 	if (rv < 0) {
-		printf("dump write error %d errno %d\n", rv, errno);;
+		printf("dump write error %d errno %d\n", rv, errno);
 		return -1;
 	}
 
@@ -424,7 +436,11 @@ int do_plock_dump(int argc, char **argv, int fd)
 		rv = read(fd, inbuf, sizeof(inbuf));
 		if (rv <= 0)
 			break;
-		write(STDOUT_FILENO, inbuf, rv);
+		rv = write(STDOUT_FILENO, inbuf, rv);
+		if (rv < 0) {
+			printf("dump write error %d errno %d\n", rv, errno);
+			return  -1;
+		}
 	}
 
 	close(fd);
