@@ -1,3 +1,22 @@
+/*
+  Copyright Red Hat, Inc. 2002-2004
+  Copyright Mission Critical Linux, Inc. 2000
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by the
+  Free Software Foundation; either version 2, or (at your option) any
+  later version.
+
+  This program is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; see the file COPYING.  If not, write to the
+  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge, 
+  MA 02139, USA.
+*/
 #include <message.h>
 #include <platform.h>
 #include <ccs.h>
@@ -17,7 +36,6 @@
 #include <malloc.h>
 #include <cman-private.h>
 #include <event.h>
-#include <members.h>
 
 #define L_SHUTDOWN (1<<2)
 #define L_SYS (1<<1)
@@ -32,7 +50,7 @@ void set_transition_throttling(int);
 void node_event(int, int, int, int);
 void node_event_q(int, int, int, int);
 int daemon_init(char *);
-int init_resource_groups(int, int);
+int init_resource_groups(int);
 void kill_resource_groups(void);
 void set_my_id(int);
 void flag_shutdown(int sig);
@@ -43,15 +61,11 @@ int svc_exists(char *);
 int watchdog_init(void);
 int32_t master_event_callback(char *key, uint64_t viewno, void *data, uint32_t datalen);
 
-int node_has_fencing(int nodeid);
-int fence_domain_joined(void);
-
 int shutdown_pending = 0, running = 1, need_reconfigure = 0;
 char debug = 0; /* XXX* */
 static int signalled = 0;
 static uint8_t ALIGNED port = RG_PORT;
 static char *rgmanager_lsname = "rgmanager"; /* XXX default */
-static int status_poll_interval = DEFAULT_CHECK_INTERVAL;
 
 int next_node_id(cluster_member_list_t *membership, int me);
 void malloc_dump_table(FILE *, size_t, size_t);
@@ -703,13 +717,13 @@ event_loop(msgctx_t *localctx, msgctx_t *clusterctx)
 	struct timeval tv;
 	int nodeid;
 
-	tv.tv_sec = status_poll_interval;
+	tv.tv_sec = 10;
 	tv.tv_usec = 0;
 
 	if (signalled) {
 		signalled = 0;
-
-		dump_internal_state("/var/lib/cluster/rgmanager-dump");
+ 
+		dump_internal_state("/tmp/rgmanager-dump");
 	}
 
 	while (running && (tv.tv_sec || tv.tv_usec)) {
@@ -863,21 +877,6 @@ configure_rgmanager(int ccsfd, int dbg)
 		free(v);
 	}
 
-	if (ccs_get(ccsfd, "/cluster/rm/@status_poll_interval", &v) == 0) {
-		status_poll_interval = atoi(v);
-		if (status_poll_interval >= 1) {
-			clulog(LOG_NOTICE,
-			       "Status Polling Interval set to %d\n", v);
-		} else {
-			clulog(LOG_WARNING, "Ignoring illegal "
-			       "status_poll_interval of %s\n", v);
-			status_poll_interval = 10;
-		}
-		
-		free(v);
-	}
-
-
 	if (internal)
 		ccs_disconnect(ccsfd);
 
@@ -912,25 +911,7 @@ clu_initialize(cman_handle_t *ch)
 		while (cman_is_quorate(*ch) == 0) {
 			sleep(1);
 		}
-		clulog(LOG_NOTICE, "Quorum formed\n");
-	}
-
-}
-
-
-void
-wait_for_fencing(void)
-{
-        if (node_has_fencing(my_id()) && !fence_domain_joined()) {
-		clulog(LOG_INFO, "Waiting for fence domain join operation "
-		       "to complete\n");
-
-		while (fence_domain_joined() == 0)
-			sleep(1);
-		clulog(LOG_INFO, "Fence domain joined\n");
-	} else {
-		clulog(LOG_DEBUG, "Fence domain already joined "
-		       "or no fencing configured\n");
+		clulog(LOG_NOTICE, "Quorum formed, starting\n");
 	}
 }
 
@@ -962,7 +943,7 @@ void dump_thread_states(FILE *);
 int
 main(int argc, char **argv)
 {
-	int rv, do_init = 1;
+	int rv;
 	char foreground = 0, wd = 1;
 	cman_node_t me;
 	msgctx_t *cluster_ctx;
@@ -970,7 +951,7 @@ main(int argc, char **argv)
 	pthread_t th;
 	cman_handle_t clu = NULL;
 
-	while ((rv = getopt(argc, argv, "wfdN")) != EOF) {
+	while ((rv = getopt(argc, argv, "wfd")) != EOF) {
 		switch (rv) {
 		case 'w':
 			wd = 0;
@@ -978,9 +959,6 @@ main(int argc, char **argv)
 		case 'd':
 			debug = 1;
 			break;
-		case 'N':
-			do_init = 0;
-			break;
 		case 'f':
 			foreground = 1;
 			break;
@@ -1039,8 +1017,6 @@ main(int argc, char **argv)
 
 	clulog(LOG_INFO, "I am node #%d\n", my_id());
 
-	wait_for_fencing();
-
 	/*
 	   We know we're quorate.  At this point, we need to
 	   read the resource group trees from ccsd.
@@ -1048,7 +1024,7 @@ main(int argc, char **argv)
 	configure_rgmanager(-1, debug);
 	clulog(LOG_NOTICE, "Resource Group Manager Starting\n");
 
-	if (init_resource_groups(0, do_init) != 0) {
+	if (init_resource_groups(0) != 0) {
 		clulog(LOG_CRIT, "#8: Couldn't initialize services\n");
 		return -1;
 	}
